
import os
import sys
import ldap
import time
from dsadmin import DSAdmin, Entry, LEAF_TYPE

host1 = "localhost.localdomain"
if len(sys.argv) > 1:
    host1 = sys.argv[1]
host2 = host1
port1 = 1200
port2 = port1 + 10
host3 = host2
port3 = port2 + 10

basedn = 'dc=example,dc=com'
proxycn = "replrepl"
proxydn = "cn=%s,cn=config" % proxycn
proxypw = "replrepl"

m1replargs = {
	'suffix': basedn,
	'bename': "userRoot",
	'binddn': proxydn,
	'bindcn': proxycn,
	'bindpw': proxypw
}
#os.environ['USE_GDB'] = "1"
m1 = DSAdmin.createAndSetupReplica({
	'newrootpw': 'password',
	'newhost': host1,
	'newport': port1,
	'newinst': 'm1',
	'newsuffix': basedn,
    'no_admin': True,
    'InstallLdifFile': os.environ.get('PREFIX', '/usr') + "/share/dirsrv/data/Example.ldif"
}
, m1replargs
)
#del os.environ['USE_GDB']
m2replargs = m1replargs
m2 = DSAdmin.createAndSetupReplica({
	'newrootpw': 'password',
	'newhost': host2,
	'newport': port2,
	'newinst': 'm2',
	'newsuffix': basedn,
    'no_admin': True
}
, m2replargs
)

c1replargs = m1replargs
c1replargs['type'] = LEAF_TYPE

#os.environ['USE_GDB'] = "1"
c1 = DSAdmin.createInstance({
	'newrootpw': 'password',
	'newhost': host3,
	'newport': port3,
	'newinst': 'c1',
	'newsuffix': "dc=dummy",
    'no_admin': True
}
#, c1replargs
)
#del os.environ['USE_GDB'] = "1"

print "create agreements and init consumers"
agmtm1tom2 = m1.setupAgreement(m2, m1replargs)
m1.startReplication_async(agmtm1tom2)
print "waiting for init to finish"
m1.waitForReplInit(agmtm1tom2)
agmtm2tom1 = m2.setupAgreement(m1, m2replargs)

print "setup m1 and m2 to be chaining farm servers"
m1.setupChainingFarm(basedn, proxydn, proxycn, proxypw)
m2.setupChainingFarm(basedn, proxydn, proxycn, proxypw)
url = "ldap://%s:%d %s:%d/" % (host1, port1, host2, port2)
print "setup c1 to chain to", url
c1.setupChainingMux(basedn, False, proxydn, proxypw, url)

print "bind to c1 as uid=scarter"
ents = m1.search_s(basedn, ldap.SCOPE_SUBTREE, "uid=scarter")
userdn = ents[0].dn
userpw = "sprain"

print "turn on error logging on c1"

userc1 = ldap.initialize("ldap://%s:%d" % (host3, port3))
userc1.simple_bind_s(userdn, userpw)
userc1.search_s(userdn, ldap.SCOPE_BASE)

print "shutdown m1 - see if still can search"
m1.stop()

userc1.search_s(userdn, ldap.SCOPE_BASE)

print "shutdown m2 - see if still can search"
m2.stop()

try:
    userc1.search_s(userdn, ldap.SCOPE_BASE)
except ldap.LDAPError, e:
    print "Could not search c1", e

print "start up m2 - see if can search now"
m2.start()

userc1.search_s(userdn, ldap.SCOPE_BASE)
